@@ -57,15 +57,15 @@ gboolean queen_beecon_dbus_monitor_parse_match(DBusMessage *message, gchar *rule
 
 	if (*p=='\0') {g_free(s);return FALSE;}
 	while (*p!=0 && t<16) {
-		qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) t=%d inquote=%d inkey=%d invalue=%d *p=%c p=%p(%s) k=%p(%s) v=%p(%s)", NULL, t, inquote, inkey, invalue, *p, p, p, k, k, v, v);
+		//qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) t=%d inquote=%d inkey=%d invalue=%d *p=%c p=%p(%s) k=%p(%s) v=%p(%s)", NULL, t, inquote, inkey, invalue, *p, p, p, k, k, v, v);
 		switch (*p) {
 		case '\\':
-			qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) t=%d inquote=%d inkey=%d invalue=%d *p=%c", NULL, t, inquote, inkey, invalue, *p);
+			//qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) t=%d inquote=%d inkey=%d invalue=%d *p=%c", NULL, t, inquote, inkey, invalue, *p);
 			if (invalue) {inquote=TRUE;p++;break;}
 			p++;
 			break;
 		case '\'':
-			qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) t=%d inquote=%d inkey=%d invalue=%d *p=%c", NULL, t, inquote, inkey, invalue, *p);
+			//qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) t=%d inquote=%d inkey=%d invalue=%d *p=%c", NULL, t, inquote, inkey, invalue, *p);
 			if (inquote) {inquote=FALSE;p++;}
 			if (inkey) {inkey=FALSE;invalue=TRUE;p++;v=p;break;} // found ' value leader
 			if (invalue&&!inquote) {*p='\0';tokens[t].val=g_strdup(v);p++;invalue=FALSE;t++;break;} // found ' value trailer
@@ -73,25 +73,25 @@ gboolean queen_beecon_dbus_monitor_parse_match(DBusMessage *message, gchar *rule
 			break;
 		case ' ':
 		case '\t':
-			qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) t=%d inquote=%d inkey=%d invalue=%d *p=%c", NULL, t, inquote, inkey, invalue, *p);
+			//qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) t=%d inquote=%d inkey=%d invalue=%d *p=%c", NULL, t, inquote, inkey, invalue, *p);
 			inquote = FALSE;
 			if (!invalue) *p='\0'; // leading or trailing blanks or tabs surrounding key or value
 			p++;
 			break;
 		case '=':
-			qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) t=%d inquote=%d inkey=%d invalue=%d *p=%c", NULL, t, inquote, inkey, invalue, *p);
+			//qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) t=%d inquote=%d inkey=%d invalue=%d *p=%c", NULL, t, inquote, inkey, invalue, *p);
 			inquote = FALSE;
 			if (inkey) {*p='\0';tokens[t].key=g_strdup(k);p++;break;}
 			p++;
 			break;
 		case ',':
-			qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) t=%d inquote=%d inkey=%d invalue=%d *p=%c", NULL, t, inquote, inkey, invalue, *p);
+			//qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) t=%d inquote=%d inkey=%d invalue=%d *p=%c", NULL, t, inquote, inkey, invalue, *p);
 			inquote = FALSE;
 			if (!invalue) {p++;k=p;inkey=FALSE;break;}
 			p++;
 			break;
 		default:
-			qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V3, "(%p) t=%d inquote=%d inkey=%d invalue=%d *p=%c", NULL, t, inquote, inkey, invalue, *p);
+			//qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) t=%d inquote=%d inkey=%d invalue=%d *p=%c", NULL, t, inquote, inkey, invalue, *p);
 			if (!inkey&&!invalue){k=p;inkey=TRUE;}
 			p++;
 			break;
