@@ -396,12 +396,12 @@ gboolean queen_beecon_dbus_cb_dbus_logger_action (QueenBeecon *self, const gchar
 {
 	qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V2, "(%p) %s %s", self, G_STRFUNC, action);
 	if (self->priv->dMM) hildon_banner_show_informationf (NULL, NULL, "logger_action@qbw %s", action);
-	if (!g_strcmp0(action,"disable")) {qbw_logger(QBW_LOGGER_CHANGE_VERBOSITY, QBW_LOGGER_VNULL, NULL);return TRUE;}
-	if (!g_strcmp0(action,"v0")) {qbw_logger(QBW_LOGGER_CHANGE_VERBOSITY, QBW_LOGGER_V0, NULL);return TRUE;}
-	if (!g_strcmp0(action,"v1")) {qbw_logger(QBW_LOGGER_CHANGE_VERBOSITY, QBW_LOGGER_V1, NULL);return TRUE;}
-	if (!g_strcmp0(action,"v2")) {qbw_logger(QBW_LOGGER_CHANGE_VERBOSITY, QBW_LOGGER_V2, NULL);return TRUE;}
-	if (!g_strcmp0(action,"v3")) {qbw_logger(QBW_LOGGER_CHANGE_VERBOSITY, QBW_LOGGER_V3, NULL);return TRUE;}
-	if (!g_strcmp0(action,"v4")) {qbw_logger(QBW_LOGGER_CHANGE_VERBOSITY, QBW_LOGGER_V4, NULL);return TRUE;}
+	if (!g_strcmp0(action,"disable")) {qbw_logger(QBW_LOGGER_SET_VERBOSITY, QBW_LOGGER_VNULL, NULL);return TRUE;}
+	if (!g_strcmp0(action,"v0")) {qbw_logger(QBW_LOGGER_SET_VERBOSITY, QBW_LOGGER_V0, NULL);return TRUE;}
+	if (!g_strcmp0(action,"v1")) {qbw_logger(QBW_LOGGER_SET_VERBOSITY, QBW_LOGGER_V1, NULL);return TRUE;}
+	if (!g_strcmp0(action,"v2")) {qbw_logger(QBW_LOGGER_SET_VERBOSITY, QBW_LOGGER_V2, NULL);return TRUE;}
+	if (!g_strcmp0(action,"v3")) {qbw_logger(QBW_LOGGER_SET_VERBOSITY, QBW_LOGGER_V3, NULL);return TRUE;}
+	if (!g_strcmp0(action,"v4")) {qbw_logger(QBW_LOGGER_SET_VERBOSITY, QBW_LOGGER_V4, NULL);return TRUE;}
 	if (!g_strcmp0(action,"reset")) {qbw_logger(QBW_LOGGER_RESET_LOGFILE, QBW_LOGGER_VNULL, "", NULL); return TRUE;}
 	if (!g_strcmp0(action,"flush")) {qbw_logger(QBW_LOGGER_FLUSH, QBW_LOGGER_VNULL, "", NULL); return TRUE;}
 	g_set_error (error, DBUS_GERROR, DBUS_GERROR_REMOTE_EXCEPTION, "Invalid Logger Action specified");
